@@ -4,6 +4,7 @@ from omegaconf import MISSING, DictConfig, ListConfig
 
 from .commandline import cli
 from .core import (
+    DEFAULT,
     cast,
     edit_list,
     from_dataclass,
@@ -11,10 +12,13 @@ from .core import (
     from_file,
     from_none,
     from_options,
+    from_python,
     from_string,
     merge,
     resolve,
     to_dict,
+    to_json,
+    to_python,
     to_yaml,
     unsafe_merge,
     validate,
@@ -44,6 +48,7 @@ __all__ = [
     "cli",
     "configure_logging",
     "dataclass",
+    "DEFAULT",
     "DictConfig",
     "edit_list",
     "fdict",
@@ -55,6 +60,7 @@ __all__ = [
     "from_file",
     "from_none",
     "from_options",
+    "from_python",
     "from_string",
     "get_nickname",
     "get_type",
@@ -69,6 +75,8 @@ __all__ = [
     "resolve",
     "Target",
     "to_dict",
+    "to_json",
+    "to_python",
     "to_yaml",
     "toggle_warnings",
     "traverse",
